@@ -214,6 +214,7 @@ class ProjectPluginEnum(Enum):
     INTEGRATION_ACK = 'integration_ack'
     INTEGRATION_EIS = 'integration_eis'
     INTEGRATION_EL_BUDG = 'integration_el_budg'
+    INTEGRATION_TRANSCRYPT = 'integration_transcrypt'
     JOURNAL_HOZ_OPER_CHELYAB = 'journal_hoz_oper_chelyab'
     KAZAN_REPORTS = 'kazan_reports'
     KPP_PP = 'kpp_pp'
@@ -261,6 +262,7 @@ class ProjectPluginEnum(Enum):
     SALARY_GMS_INFORMATION = 'salary.gms_information'
     SALARY_JINN_SERVICE = 'salary.jinn_service'
     SALARY_LDAP_SYNC = 'salary.ldap_sync'
+    SALARY_MCHS = 'salary.mchs'
     SALARY_NOVOSIB_ZDRAV = 'salary.novosib_zdrav'
     SALARY_PERSONNEL_RESERVE_PLUGIN = 'salary.personnel_reserve_plugin'
     SALARY_PORTAL_INTEGRATION = 'salary.portal_integration'
@@ -449,6 +451,7 @@ class ProjectPluginEnum(Enum):
                     cls.INTEGRATION_ACK,
                     cls.INTEGRATION_EIS,
                     cls.INTEGRATION_EL_BUDG,
+                    cls.INTEGRATION_TRANSCRYPT,
                     cls.JOURNAL_HOZ_OPER_CHELYAB,
                     cls.KAZAN_REPORTS,
                     cls.KPP_PP,
@@ -600,6 +603,9 @@ class ProjectPluginEnum(Enum):
             cls.INTEGRATION_EL_BUDG: (
                 cls.ACCOUNTING,
             ),
+            cls.INTEGRATION_TRANSCRYPT: (
+                cls.ACCOUNTING,
+            ),
             cls.JOURNAL_HOZ_OPER_CHELYAB: (
                 cls.ACCOUNTING,
             ),
@@ -709,6 +715,7 @@ class ProjectPluginEnum(Enum):
                     cls.SALARY_GMS_INFORMATION,
                     cls.SALARY_JINN_SERVICE,
                     cls.SALARY_LDAP_SYNC,
+                    cls.SALARY_MCHS,
                     cls.SALARY_NOVOSIB_ZDRAV,
                     cls.SALARY_PERSONNEL_RESERVE_PLUGIN,
                     cls.SALARY_PORTAL_INTEGRATION,
@@ -810,6 +817,9 @@ class ProjectPluginEnum(Enum):
             cls.SALARY_LDAP_SYNC: (
                 cls.SALARY,
             ),
+            cls.SALARY_MCHS: (
+                cls.SALARY,
+            ),
             cls.SALARY_NOVOSIB_ZDRAV: (
                 cls.SALARY_ACCOUNTING_INTEGRATION,
             ),
